#!/bin/sh

. /etc/tune-profiles/functions

start() {
	set_cpu_governor performance
	enable_transparent_hugepages

	# Find non-root and non-boot partitions, disable barriers on them
	rootvol=$(df -h / | grep "^/dev" | awk '{print $1}')
	bootvol=$(df -h /boot | grep "^/dev" | awk '{print $1}')
	volumes=$(df -hl --exclude=tmpfs | grep "^/dev" | awk '{print $1}')

	nobarriervols=$(echo "$volumes" | grep -v $rootvol | grep -v $bootvol)
	remount_partitions nobarrier $nobarriervols
	for d in $DISKS ; do 
		blkdev=`basename $d`
		echo 65536 > /sys/block/$blkdev/queue/read_ahead_kb
		echo 512 > /sys/block/$blkdev/queue/nr_requests 
	done
	return 0
}

stop() {

	# Find non-root and non-boot partitions, re-enable barriers
	rootvol=$(df -h / | grep "^/dev" | awk '{print $1}')
	bootvol=$(df -h /boot | grep "^/dev" | awk '{print $1}')
	volumes=$(df -hl --exclude=tmpfs | grep "^/dev" | awk '{print $1}')

	nobarriervols=$(echo "$volumes" | grep -v $rootvol | grep -v $bootvol)
	remount_partitions barrier $nobarriervols
	for d in $DISKS ; do 
		blkdev=`basename $d`
		echo 128 > /sys/block/$blkdev/queue/read_ahead_kb
		echo 128 > /sys/block/$blkdev/queue/nr_requests
	done
	restore_cpu_governor
	restore_transparent_hugepages
	return 0
}

process $@
